@@ -17,7 +17,7 @@ ulimit -c unlimited
 host_arch="${DEB_HOST_ARCH:-$(dpkg --print-architecture)}"
 
 if [ -z "${JDK_TO_TEST+x}" ]; then
-  JDK_TO_TEST=$(echo /usr/lib/jvm/java-25-openjdk-amd64 | sed "s/-[^-]*$/-$host_arch/")
+  JDK_TO_TEST=$(echo /usr/lib/jvm/java-26-openjdk-amd64 | sed "s/-[^-]*$/-$host_arch/")
 fi
 
 if [ -z "${BOOTJDK_HOME+x}" ]; then
@@ -32,7 +32,13 @@ if [[ "armel" == *"${host_arch}"* ]]; then
   jt_options+=" -Xmx256M"
 fi
 if dpkg --compare-versions ${jtreg_version} ge 4.2; then
-  jt_options+=" -conc:auto"
+  njobs=auto
+  for opt in ${DEB_BUILD_OPTIONS:-}; do
+    if test "${opt#parallel=}" != "$opt"; then
+      njobs="${opt#parallel=}"
+    fi
+  done
+  jt_options+=" -conc:$njobs"
 fi
 
 # check java binary
